set origfile "../soc_system/soc_system/synthesis/soc_system.v"
set tmpfile  "soc_system.tmp"
set allowedversion "13.0.1"

# Verify that we're running on the correct version of Quartus

regexp {[\.0-9]+} $quartus(version) clean_version_number

if { ! [ string equal $allowedversion $clean_version_number ] } {
    post_message -type error "Only Quartus version 13.0sp1 is allowed for building this Xillydemo bundle."
    post_message "You may download the Web Edition free from Altera's site, which is adequate for this project."
    post_message "This is an annoying, yes, and noone likes to download and install another"
    post_message "Quartus revision. But please take this error as a friendly way to prevent you"
    post_message "from building an apparently working FPGA bitstream, but which is possibly"
    post_message "unreliable, resulting from emerging changes in the processor infrastructure"
    post_message "generated by Qsys for the ARM HPS. By using the correct Quartus"
    post_message "revision, you can be confident about running a stable and well-tested"
    post_message "processor environment."
    post_message "A more liberal Xillydemo bundle will be released once Altera's support for the ARM SoC has matured."
    exit 0
}

# Mangle soc_system.v
# Qsys' AXI interconnect for combining two masters is buggy regarding write
# operations. Since one of the masters, xillyvga, only reads, mangle the
# toplevel module, and connect the second master (xillybus) directly to
# the HPS, hence bypassing the buggy piece of logic.
# This hack will be removed once Qsys gets this right.

if { [catch {open $origfile r} fi] } {
    post_message -type error "Failed to open $origfile"
    post_message "It looks like you didn't generate the soc_system project with Qsys before"
    post_message "attempting to build the Quartus project. Please refer to the Getting Started"
    post_message "guide from Xillybus for the correct sequence of actions."
    # The error is caused by the message above anyhow, so exit with 0
    exit 0
}

gets $fi line

if { [ string match *mangled* $line ] } {
    # The file is already mangled. Nothing to do.
    close $fi
    exit 0
}

if { [catch {open $tmpfile w} fo] } {
    post_message -type error "Failed to open temporary file $tmpfile for output"
    close $fi
    exit 0
}

puts $fo "$line (mangled by preflow.tcl)"

while {[gets $fi line] != -1} {
    if { [ regexp {\.f2h_(AW|W|B)} $line ] } {
	regsub {(\.f2h_.*?\()hps_.*_(.*)\)} $line "\\1xillybus_0_xillybus_axi_master_\\2)" line
    }

    if { [ regexp {^(.*?)\.((?:w|aw|b)\w+).*xillybus_0_xillybus_axi_master_(\w+)(\).*)$} \
	       $line junk pre cmp1 cmp2 post ] && \
	     [ string equal $cmp1 $cmp2 ] } {
	set replacewith ""
	if { [ string match \[aw\]*valid $cmp1 ] } {
	    set replacewith "1'b0"
	}
	
	if { [ string equal "bready" $cmp1 ] } {
	    set replacewith "1'b1"
	}

	set line "$pre.$cmp1 ($replacewith$post"
    }    

    # This last modification isn't necessary functionally, but intentionally
    # makes the module's ports incompatible. This prevents an accidental
    # use of a non-mangled soc_system module, which would appear to work,
    # but suffer from unreliable data transport.

    set line [ string map { xillybus_0_conduit_xillybus_ xillybus_0_conduit_ } $line ]

    puts $fo $line
}

close $fo
close $fi

# Overwrite the original file
if { [catch { file rename -force $tmpfile $origfile } ] } {
    post_message -type error "Failed to overwrite $origfile. Please report this error unless you've made changes in file permissions"
}
