module xillybus_lite
  (
   input          S_AXI_ACLK,
   input 	  S_AXI_ARESETN,
   input [15:0]	  S_AXI_AWADDR,
   input 	  S_AXI_AWVALID,
   input [2:0] 	  S_AXI_AWPROT, // Ignored
   input [3:0] 	  S_AXI_AWLEN, // Ignored. Relying on WLAST.
   input [11:0]   S_AXI_AWID,
   input [2:0] 	  S_AXI_AWSIZE, // Ignored, assumed to be 32 bit
   input [1:0] 	  S_AXI_AWBURST, // Ignored, assumed incremental
   input [1:0] 	  S_AXI_AWLOCK, // Ignored. Locking is meaningless
   input [3:0] 	  S_AXI_AWCACHE, // Ingored. Caching is meaningless
   input [4:0] 	  S_AXI_AWUSER, // Ignored.
   input [31:0]   S_AXI_WDATA,
   input [3:0] 	  S_AXI_WSTRB, // Ignored
   input 	  S_AXI_WVALID,
   input [11:0]   S_AXI_WID, // Ignored
   input 	  S_AXI_WLAST,   
   input 	  S_AXI_BREADY,
   input [15:0]	  S_AXI_ARADDR, 
   input [3:0] 	  S_AXI_ARLEN,
   input [2:0] 	  S_AXI_ARPROT, // Ignored
   input 	  S_AXI_ARVALID,
   input [11:0]   S_AXI_ARID,
   input [2:0] 	  S_AXI_ARSIZE, // Ignored, assumed to be 32 bit
   input [1:0] 	  S_AXI_ARBURST, // Ignored, assumed incremental
   input [1:0] 	  S_AXI_ARLOCK, // Ignored. Locking is meaningless
   input [3:0] 	  S_AXI_ARCACHE, // Ingored. Caching is meaningless
   input [4:0] 	  S_AXI_ARUSER, // Ignored.

   input 	  S_AXI_RREADY,
   output    	  S_AXI_ARREADY,
   output [31:0]  S_AXI_RDATA,
   output [1:0]   S_AXI_RRESP,
   output    	  S_AXI_RVALID,
   output [11:0]  S_AXI_RID,
   output    	  S_AXI_RLAST,
   output    	  S_AXI_WREADY,
   output [1:0]   S_AXI_BRESP,
   output [11:0]  S_AXI_BID,
   output    	  S_AXI_BVALID,
   output    	  S_AXI_AWREADY,

   output         host_interrupt, 
  
   output            user_clk,
   output    	     user_wren,
   output [3:0]      user_wstrb,
   output    	     user_rden,
   input [31:0]      user_rd_data,
   output [31:0]     user_wr_data,
   output [31:0]     user_addr,

   input             user_irq
   );
   
   xillybus_lite_core xillybus_lite_core_inst
     (    
      .S_AXI_ARREADY			(S_AXI_ARREADY),
      .S_AXI_RDATA			(S_AXI_RDATA),
      .S_AXI_RRESP			(S_AXI_RRESP),
      .S_AXI_RVALID			(S_AXI_RVALID),
      .S_AXI_RID			(S_AXI_RID),
      .S_AXI_RLAST			(S_AXI_RLAST),
      .S_AXI_WREADY			(S_AXI_WREADY),
      .S_AXI_BRESP			(S_AXI_BRESP),
      .S_AXI_BID			(S_AXI_BID),
      .S_AXI_BVALID			(S_AXI_BVALID),
      .S_AXI_AWREADY			(S_AXI_AWREADY),
      .host_interrupt			(host_interrupt),
      .user_clk				(user_clk),
      .user_wren			(user_wren),
      .user_wstrb			(user_wstrb),
      .user_rden			(user_rden),
      .user_wr_data			(user_wr_data),
      .user_addr			(user_addr),
      .S_AXI_ACLK			(S_AXI_ACLK),
      .S_AXI_ARESETN			(S_AXI_ARESETN),
      .S_AXI_AWADDR			(S_AXI_AWADDR),
      .S_AXI_AWVALID			(S_AXI_AWVALID),
      .S_AXI_AWPROT			(S_AXI_AWPROT),
      .S_AXI_AWLEN			(S_AXI_AWLEN),
      .S_AXI_AWID			(S_AXI_AWID),
      .S_AXI_AWSIZE			(S_AXI_AWSIZE),
      .S_AXI_AWBURST			(S_AXI_AWBURST),
      .S_AXI_AWLOCK			(S_AXI_AWLOCK),
      .S_AXI_AWCACHE			(S_AXI_AWCACHE),
      .S_AXI_AWUSER			(S_AXI_AWUSER),
      .S_AXI_WDATA			(S_AXI_WDATA),
      .S_AXI_WSTRB			(S_AXI_WSTRB),
      .S_AXI_WVALID			(S_AXI_WVALID),
      .S_AXI_WID			(S_AXI_WID),
      .S_AXI_WLAST			(S_AXI_WLAST),
      .S_AXI_BREADY			(S_AXI_BREADY),
      .S_AXI_ARADDR			(S_AXI_ARADDR),
      .S_AXI_ARLEN			(S_AXI_ARLEN),
      .S_AXI_ARPROT			(S_AXI_ARPROT),
      .S_AXI_ARVALID			(S_AXI_ARVALID),
      .S_AXI_ARID			(S_AXI_ARID),
      .S_AXI_ARSIZE			(S_AXI_ARSIZE),
      .S_AXI_ARBURST			(S_AXI_ARBURST),
      .S_AXI_ARLOCK			(S_AXI_ARLOCK),
      .S_AXI_ARCACHE			(S_AXI_ARCACHE),
      .S_AXI_ARUSER			(S_AXI_ARUSER),
      .S_AXI_RREADY			(S_AXI_RREADY),
      .user_rd_data			(user_rd_data),
      .user_irq				(user_irq));  
endmodule
